use std::path::PathBuf;

use clap::Parser;

#[derive(Debug, Parser)]
#[clap(author, version, about)]
pub struct Cli {
    #[clap(
        short,
        parse(from_occurrences),
        help = "log level to use, defaults to warning (0) up to trace (3+)."
    )]
    pub verbosity: usize,

    #[clap(
        long,
        env = "EVALUATION_SYSTEM_CONFIG_FILE",
        help = concat!("directory with freva config files. If not set, defaults to an OS specific default",
            " e.g. on Linux ~/.config/freva")
    )]
    pub config_dir: Option<PathBuf>,

    #[clap(flatten)]
    pub opts: IngestOpts,
}

#[derive(Debug, Parser)]
pub struct IngestOpts {
    #[clap(long)]
    pub data_dir: PathBuf,

    #[clap(long, help = "size of batches to send to solr", default_value = "50")]
    pub batch_size: usize,
}
