use freva::drs::Config;
use freva::solr::Solr;
use wiremock::MockServer;

pub const REPO_ROOT: &str = concat!(env!("CARGO_MANIFEST_DIR"), "/..");

pub fn log_init() {
    env_logger::init();
}

pub async fn solr_server() -> (MockServer, Solr) {
    let server = MockServer::start().await;

    let url = reqwest::Url::parse(&server.uri()).unwrap();
    let domain = url.host_str().unwrap().to_owned();
    let port = url.port();

    let solr = Solr::new(domain, port, None);
    assert!(solr.is_ok(), "invalid solr address");
    (server, solr.unwrap())
}

pub fn test_config() -> Config {
    let string = format!(
        r#"
            [observations]
                root_dir = "{REPO_ROOT}/.docker/data"
                parts_dir = [
                    "project", "product", "institute", "model", "experiment", "time_frequency", "realm",
                    "cmor_table", "ensemble", "version", "variable", "file_name"
                ]
                parts_dataset = [
                    "project", "product", "institute", "model", "experiment", "time_frequency", "realm",
                    "cmor_table", "ensemble", "", "variable"
                ]
                parts_versioned_dataset = [
                    "project", "product", "institute", "model", "experiment", "time_frequency", "realm",
                    "cmor_table", "ensemble", "version", "variable"
                ]
                parts_file_name = ["variable", "time_frequency", "experiment", "level", "version", "time"]
                parts_time = "start_time-end_time"
                data_type = "observations"

                [observations.defaults]
                project = "observations"
            "#,
    );
    Config::try_from(&string).unwrap()
}
