use camino::Utf8PathBuf;
use freva::drs::metadata::Activity;
use wiremock::{
    matchers::{method, path},
    Mock, ResponseTemplate,
};

mod common;

#[tokio::test]
async fn test_ingest() {
    common::log_init();
    let (mock, solr) = common::solr_server().await;
    Mock::given(method("POST"))
        .and(path("/solr/files/update/json/docs"))
        .respond_with(ResponseTemplate::new(200))
        .mount(&mock)
        .await;
    Mock::given(method("POST"))
        .and(path("/solr/latest/update/json/docs"))
        .respond_with(ResponseTemplate::new(200))
        .mount(&mock)
        .await;

    let config_dir = Utf8PathBuf::from(common::REPO_ROOT).join(".docker");
    let data_dir = config_dir.join("data");
    let drs_config = common::test_config();

    let result = freva::drs::ingest(&solr, &drs_config, &data_dir, 10, None, None).await;
    assert!(result.is_ok());
    let report = result.unwrap();
    assert_eq!(1, report.structures.len());
    let structure_report = &report.structures[0];
    assert_eq!(
        &Activity("observations".to_owned()),
        structure_report.structure.activity()
    );
    assert_eq!(24, structure_report.sent);
    assert_eq!(0, structure_report.skipped);
}
